@@ -1,4 +1,4 @@
-# Copyright 2023 DARWIN EU (C)
+# Copyright 2024 DARWIN EU (C)
 #
 # This file is part of PatientProfiles
 #
@@ -417,7 +417,13 @@ checkStrata <- function(list, table, type = "strata") {
       cli::cli_abort(errorMessage)
     }
     if (!all(unlist(list) %in% colnames(table))) {
-      cli::cli_abort(errorMessage)
+      notPresent <- list |> unlist() |> unique()
+      notPresent <- notPresent[! notPresent %in% colnames(table)]
+      cli::cli_abort(paste0(
+        errorMessage,
+        ". The following columns were not found in the data: ",
+        paste0(notPresent, collapse = ", ")
+      ))
     }
   }
 }
@@ -438,6 +444,15 @@ checkVariablesFunctions <- function(variables, estimates, table) {
     estimates <- estimates[order(names(estimates))]
   }
 
+  if (length(variables) == 0) {
+    return(dplyr::tibble(
+      "variable_name" = character(),
+      "estimate_name" = character(),
+      "variable_type" = character(),
+      "estimate_type" = character()
+    ))
+  }
+
   functions <- lapply(seq_along(variables), function(k){
     tidyr::expand_grid(
       variable_name = variables[[k]],
