@@ -1,3 +1,14 @@
+on_cran <- function(){
+  !interactive() && !isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false")))
+}
+if (!on_cran()) {
+  withr::local_envvar(
+    R_USER_CACHE_DIR = tempfile(),
+    .local_envir = teardown_env(),
+    EUNOMIA_DATA_FOLDER = Sys.getenv("EUNOMIA_DATA_FOLDER", unset = tempfile())
+  )
+  CDMConnector::downloadEunomiaData(overwrite = TRUE)
+}
 connection <- function(dbToTest) {
   switch(
     dbToTest,
@@ -34,6 +45,6 @@ connectionDetails <- connection(Sys.getenv("DB_TO_TEST", "duckdb"))
 emptyCohort <- dplyr::tibble(
   cohort_definition_id = numeric(),
   subject_id = numeric(),
-  cohort_start_date = date(),
-  cohort_end_date = date()
+  cohort_start_date = as.Date(character()),
+  cohort_end_date = as.Date(character())
 )
